@@ -27,9 +27,8 @@
 #include "extractors/taglibextractor.h"
 #include "mimeutils.h"
 
-#include <QDebug>
+#include <QSet>
 #include <QTest>
-#include <QDir>
 
 using namespace KFileMetaData;
 
@@ -585,7 +584,7 @@ void  TagLibExtractorTest::testNoMetadata()
     const auto excessKeys = resultKeys.toSet() - expectedKeys.toSet();
     const auto missingKeys = expectedKeys.toSet() - resultKeys.toSet();
     if (!excessKeys.isEmpty()) {
-        const auto propNames =  propertyEnumNames(excessKeys.toList()).join(QLatin1String(", "));
+        const auto propNames =  propertyEnumNames(excessKeys.values()).join(QLatin1String(", "));
         if (failMessage.isEmpty()) {
             const auto message = QStringLiteral("Excess properties: %1").arg(propNames);
             QWARN(qPrintable(message));
@@ -594,7 +593,7 @@ void  TagLibExtractorTest::testNoMetadata()
         }
     } else if (!missingKeys.isEmpty()) {
         const auto message = QStringLiteral("Missing properties: %1")
-                .arg(propertyEnumNames(missingKeys.toList()).join(QLatin1String(", ")));
+                .arg(propertyEnumNames(missingKeys.values()).join(QLatin1String(", ")));
         QWARN(qPrintable(message));
     }
     QCOMPARE(resultKeys, expectedKeys);
@@ -602,7 +601,7 @@ void  TagLibExtractorTest::testNoMetadata()
         auto excessKeys = resultKeys.toSet() - expectedKeys.toSet();
         const auto message = QStringLiteral("%1: %2")
                 .arg(failMessage)
-                .arg(propertyEnumNames(excessKeys.toList()).join(QLatin1String(", ")));
+                .arg(propertyEnumNames(excessKeys.values()).join(QLatin1String(", ")));
         QEXPECT_FAIL("", qPrintable(message), Continue);
     }
     QCOMPARE(resultKeys, expectedKeys);
